pub struct CostMetrics {
pub total_usd: f64,
pub daily_avg_usd: f64,
pub last_day_usd: f64,
pub by_model: Vec<ModelCost>,
}Expand description
Cost metrics for a project within a time range.
Fields
total_usd: f64daily_avg_usd: f64last_day_usd: f64Cost of the most recent day in the period (for anomaly detection).
by_model: Vec<ModelCost>Trait Implementations
Sourceimpl Clone for CostMetrics
impl Clone for CostMetrics
Sourcefn clone(&self) -> CostMetrics
fn clone(&self) -> CostMetrics
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CostMetrics
impl Debug for CostMetrics
Sourceimpl<'de> Deserialize<'de> for CostMetrics
impl<'de> Deserialize<'de> for CostMetrics
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more